@@ -117,7 +117,7 @@ def _value_average(node: dict, default=0):
 
 
 def _find_linked_node(node_map: dict, node: dict):
-    return node_map.get(node.get('type'), {}).get(node.get('id'))
+    return node_map.get(node.get('type'), {}).get(node.get('id'), {})
 
 
 def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
