@@ -29,6 +29,18 @@ def validate_value(products: list):
     return _filter_list_errors(map(validate, enumerate(products)))
 
 
+MAX_PRIMARY_PRODUCTS = 1
+
+
+def validate_primary(products: list):
+    primary = list(filter(lambda p: p.get('primary', False), products))
+    return len(primary) <= MAX_PRIMARY_PRODUCTS or {
+        'level': 'error',
+        'dataPath': '.products',
+        'message': f"only {MAX_PRIMARY_PRODUCTS} primary product allowed"
+    }
+
+
 def _get_excreta_term(cycle: dict):
     product = find_primary_product(cycle) or {}
     term_id = product.get('term', {}).get('@id')
