@@ -1,5 +1,4 @@
 import os
-from typing import List
 from concurrent.futures import ThreadPoolExecutor
 from functools import reduce
 import re
@@ -8,7 +7,7 @@ from hestia_earth.utils.tools import flatten, list_sum
 from hestia_earth.validation.geojson import get_geojson_area
 from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id
 from hestia_earth.validation.utils import (
-    update_error_path, _filter_list_errors, _next_error, _same_properties, _value_average,
+    update_error_path, _filter_list_errors, _next_error, _value_average,
     _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key,
     _list_except_item, _dict_without_key, _hash_dict
 )
@@ -136,21 +135,6 @@ def validate_nodes_duplicates(node: dict, node_by_hash: dict):
     )] if len(duplicates) > 0 else []
 
 
-def validate_list_duplicates(node: dict, list_key: str, props: List[str]):
-    def validate(values: tuple):
-        [index, blank_node] = values
-        values = node[list_key].copy()
-        values.pop(index)
-        duplicates = list(filter(_same_properties(blank_node, props), values))
-        return len(duplicates) == 0 or {
-            'level': 'error',
-            'dataPath': f".{list_key}[{index}]",
-            'message': f"Duplicates found. Please make sure there is only one entry with the same {', '.join(props)}"
-        }
-
-    return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
-
-
 def validate_list_duplicate_values(node: dict, list_key: str, prop: str, value: str):
     values = node.get(list_key, [])
     duplicates = list(filter(lambda v: _get_dict_key(v, prop) == value, values))
